QUALIFIRE_API_KEY_ENV_VAR = "QUALIFIRE_API_KEY"
QUALIFIRE_BASE_URL_ENV_VAR = "QUALIFIRE_BASE_URL"
QUALIFIRE_TRACING_URL_ENV_VAR = "QUALIFIRE_TRACING_URL"
_DEFAULT_BASE_URL = "https://api.qualifire.ai/"
_DEFAULT_TRACING_URL = "https://tracing.qualifire.ai"
